import { TypeOrmCrudService } from "@nestjsx/crud-typeorm";
import { DeepPartial, DeleteResult, EntityManager, EntityTarget, FindManyOptions, FindOneOptions, FindOptionsWhere, Repository, UpdateResult } from "typeorm";
type ExtendedEntity<Entity> = EntityTarget<Entity> & {
    relations: any[];
    recursiveRelations: any[];
};
export declare abstract class ServiceBase<Entity> extends TypeOrmCrudService<Entity> {
    protected repo: Repository<Entity>;
    protected readonly _entity: ExtendedEntity<Entity>;
    protected readonly entity: EntityTarget<Entity>;
    protected relations: string[];
    protected recursiveRelations: string[];
    constructor(repo: Repository<Entity>, _entity: ExtendedEntity<Entity>);
    findOneBy(options?: FindOneOptions<Entity>, manager?: EntityManager): Promise<Entity>;
    findAllBy(options?: FindManyOptions<Entity>, manager?: EntityManager): Promise<Entity[]>;
    createOneBy(params: DeepPartial<Entity>, manager?: EntityManager): Promise<Entity>;
    createAllBy(params: DeepPartial<Entity>[], manager?: EntityManager): Promise<Entity[]>;
    createOneIfNotExistBy(params: DeepPartial<Entity>, manager?: EntityManager): Promise<Entity>;
    createOrUpdateAllBy(params: DeepPartial<Entity>[], conflictPathsOrOptions: string[], manager?: EntityManager): Promise<Entity[]>;
    updateOneBy(where: string | number | Date | FindOptionsWhere<Entity>, set: {
        [K in keyof Entity]?: any;
    }, manager?: EntityManager): Promise<UpdateResult>;
    deleteOneBy(where?: FindOptionsWhere<Entity>, manager?: EntityManager): Promise<DeleteResult>;
}
export {};
