"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceBase = void 0;
const crud_typeorm_1 = require("@nestjsx/crud-typeorm");
class ServiceBase extends crud_typeorm_1.TypeOrmCrudService {
    constructor(repo, _entity) {
        super(repo);
        this.repo = repo;
        this._entity = _entity;
        this.entity = _entity;
        this.relations = _entity.relations;
        this.recursiveRelations = _entity.recursiveRelations;
    }
    async findOneBy(options, manager) {
        if (manager) {
            return manager.findOne(this.entity, options);
        }
        return this.findOne(options);
    }
    async findAllBy(options, manager) {
        if (manager) {
            return manager.find(this.entity, options);
        }
        return this.find(options);
    }
    async createOneBy(params, manager) {
        if (manager) {
            return (await manager.insert(this.entity, params)).generatedMaps[0];
        }
        return (await this.repo.insert(params))
            .generatedMaps[0];
    }
    async createAllBy(params, manager) {
        const createEntities = params.map((param) => this.repo.create(param));
        if (manager) {
            return manager.save(this.entity, createEntities);
        }
        return this.repo.save(createEntities);
    }
    async createOneIfNotExistBy(params, manager) {
        const createEntitie = this.repo.create(params);
        if (manager) {
            return manager.save(this.entity, createEntitie);
        }
        return this.repo.save(createEntitie);
    }
    async createOrUpdateAllBy(params, conflictPathsOrOptions, manager) {
        const createEntities = params.map((param) => this.repo.create(param));
        if (manager) {
            return (await manager.upsert(this.entity, createEntities, conflictPathsOrOptions)).generatedMaps;
        }
        return (await this.repo.upsert(createEntities, conflictPathsOrOptions))
            .generatedMaps;
    }
    async updateOneBy(where, set, manager) {
        if (manager) {
            return manager.update(this.entity, where, set);
        }
        return this.repo.update(where, set);
    }
    async deleteOneBy(where, manager) {
        if (manager) {
            return manager.delete(this.entity, where);
        }
        return this.repo.delete(where);
    }
}
exports.ServiceBase = ServiceBase;
//# sourceMappingURL=service.base.js.map